------------------------------------------
---  Copyright HDRsoft - www.hdrsoft.com   
------------------------------------------

local LrApplication = import 'LrApplication'
local LrBinding = import 'LrBinding'
local LrView = import 'LrView'
local LrDialogs = import 'LrDialogs'
local LrFunctionContext = import 'LrFunctionContext'
local LrErrors = import 'LrErrors'
local LrFileUtils = import 'LrFileUtils'
local LrPathUtils = import 'LrPathUtils'
local LrLogger = import 'LrLogger'
local prefs = import 'LrPrefs'.prefsForPlugin() 
local LrTasks = import 'LrTasks'

local myLogger = LrLogger('PhotomatixLogger')
myLogger:enable("print") 

local pmdebug=false

local cntPhotos=0
local folderPath=''

ExportToDPXSettings = {}

function ExportToDPXSettings.outputToLog(message)
	myLogger:trace(message)
end

--require 'ExportToDPXUtils'

function ExportToDPXSettings.getOptions( )

	if prefs.LrVersion==nil then
		LrDialogs.message("Plugin did not start correctly","Please check whether you invoked the plugin by choosing 'File > Plug-in Extras'","info")
		return
	end
	
	prefs.processType='none'

	LrFunctionContext.callWithContext( 'ExportToDPXSettings', function( context )

	local f = LrView.osFactory() 
	local props = LrBinding.makePropertyTable( context ) 
	props.stackWith=false
	props.chkAddSuffix=false

	props.fileNameSuffix=''
	props.outputBitDepth='10'
	props.exportDestType='1'
	props.destDir = LrPathUtils.getStandardFilePath('home')

	if prefs.outputBitDepth~=nil then
		props.outputBitDepth=prefs.outputBitDepth
	end
	
	if prefs.exportDestType~=nil then
		props.exportDestType = prefs.exportDestType
	end
	
	if prefs.destDir~=nil then
		props.destDir = prefs.destDir
	end
	
	props.okButtonEnabled = (LrFileUtils.exists(props.destDir) == 'directory')

	if (prefs.stackWith) then
		props.stackWith=prefs.stackWith
	end
	if (prefs.chkAddSuffix) then
		props.chkAddSuffix=prefs.chkAddSuffix
	end
	if (prefs.fileNameSuffix~=nil) then
		props.fileNameSuffix=prefs.fileNameSuffix
	end

	
	local LeftMarginSavePanel=135
	
	local inputFileName
	local curCatalog = LrApplication.activeCatalog()
	curCatalog:withReadAccessDo( function()
		local selectedPhoto = curCatalog.targetPhoto
		inputFileName=LrPathUtils.leafName(selectedPhoto.path)
     end)

	local exportFileSettings = f:column {
		bind_to_object = props,
		spacing = f:dialog_spacing(),
		
		f:row {
			f:static_text {
				title = LOC ("$$$/Photomatix/Settings/HeadingDXP=The file ^1 will be exported and saved as DPX.",inputFileName),
				warps=true,
				alignment = 'left',
			},
		},

--		f:group_box {
--			title = LOC "$$$/Photomatix/Settings/ExportOptions/Title=Output Options",
--			show_title=true,
--			fill_horizontal=1,
--			font = "<system>",

			
		f:row {
	--		margin_top = 10,
			f:static_text {
				title = LOC ("$$$/Photomatix/Settings/SaveDPX=Export To:"),
				alignment = 'left',
			},
		},
		
		f:row {
			margin_left = 15,
			f:radio_button {
				title =LOC "$$$/Photomatix/Settings/ExportSameFolder=Same folder as original photo",
				value = LrView.bind ("exportDestType"),
				checked_value = '1',
			},
		},
		
		f:row {
			margin_left = 15,
			f:radio_button {
				title =LOC "$$$/Photomatix/Settings/ExportSpecificFolder=Specific folder",
				value = LrView.bind ("exportDestType"),
				checked_value = '2',
			},
		},
		
		f:row {
			margin_left = 20,

			f:column {
				f:push_button {
					title = LOC "$$$/Photomatix/Settings/SelectFolder=Choose folder...",
					enabled = LrView.bind {
						key = "exportDestType", 
						transform = function(value, fromTable)
						return value == '2' end
					},
					action = function()
						paths = LrDialogs.runOpenPanel {
							title = LOC "$$$/Photomatix/Settings/SelectFolderTitle=Select destination folder for DPX files",
							prompt = LOC "$$$/Photomatix/Settings/SelectFolderButton=Select",
							canChooseFiles = false,
							canChooseDirectories = true,
							canCreateDirectories = true,
							allowsMultipleSelection = false,
							initialDirectory = props.destDir
						}
						if paths ~= nil then
							path = paths[1]
							props.destDir = path
						end
					end
				},
			},

			f:column {
				spacing = f:control_spacing() * 2/3,
				f:edit_field { 
					width_in_chars = 25, 
					value = LrView.bind ("destDir"), 
					validate = function(view, value)
						ExportToDPXSettings.outputToLog(string.format('checking %s', value))	
						local isDir = (LrFileUtils.exists(value) == 'directory')
						ExportToDPXSettings.outputToLog(string.format('checking %s: %s', value, isDir))	
						return isDir, value, LOC "$$$/Photomatix/Settings/InvalidDirectoryError=The output directory doesn't exist or is not a folder"
					end,
					enabled = LrView.bind {
						key = "exportDestType", 
						transform = function(value, fromTable)
						return value == '2' end
					},
				},
			},
		},					

		
		f:row {
			margin_top = 10,
			spacing = f:control_spacing(),
			f:column {
				place_vertical=0.5,
				f:static_text {
					title = LOC "$$$/Photomatix/Settings/BithDepthTitle=Output Bit Depth:",
				},
			},
			f:column {
				f:popup_menu {
					title = "Output bit depth:",
					value = LrView.bind ("outputBitDepth"),
					items = {
						{ title = LOC "$$$/Photomatix/Settings/Depth10=10", value = "10" },
						{ title = LOC "$$$/Photomatix/Settings/Depth12=12", value = "12" },
						{ title = LOC "$$$/Photomatix/Settings/Depth16=16", value = "16" },
					},
					--fill_horizontal=0.4,
				},
			},
		},


--		},
	}

	-- elseif (ConsistencyCheckSelectedPhotos()=="ok") then
		
		local result = LrDialogs.presentModalDialog( {
			title = LOC "$$$/Photomatix/ExportToDPXSettings/Title=Export to DPX",
			contents = exportFileSettings,
			actionVerb = LOC "$$$/Photomatix/General/Export=Export",
		} )

		if pmdebug then
		ExportToDPXSettings.outputToLog(string.format('result dialog:  %s',result))
		--ExportToDPXSettings.outputToLog(string.format('FileNameOption: %d   -  FileNameValue:  %s',props.outputFileNameOption, outputFileNameEditField.value))
		end
		

		if (result=='ok') then
			prefs.processType='ExportToDPX'
			prefs.exportDestType = props.exportDestType
			prefs.destDir = props.destDir
			
			local activeCatalog = LrApplication.activeCatalog()
			local folderPath
			activeCatalog:withReadAccessDo( function()
				local photos = activeCatalog.targetPhotos
				folderPath=LrPathUtils.parent(photos[1].path)
            end)
			if props.exportDestType == '1' then
				prefs.finalOutDir = folderPath
			else
				if props.destDir == nil or props.destDir == '' then
					prefs.finalOutDir = folderPath
				else
					prefs.finalOutDir = props.destDir
				end
			end
			prefs.outputBitDepth = props.outputBitDepth
			
			--local outputExt=string.sub(prefs.outputFormat, 1, 3)
			
			--prefs.outputPath=LrPathUtils.child(folderPath, LrPathUtils.addExtension(outputFileName, outputExt))
			--prefs.outputPath=LrFileUtils.chooseUniqueFileName(prefs.outputPath)
		end	
	
	--end
end )

end
